| Title: | Classes and Methods for Fleets and Metiers |
|---|---|
| Description: | This package contains classes and methods for modelling of fishing fleets and their activity on multiple fish stocks. |
| Authors: | Iago Mosqueira [cre], Laurence T. Kell [aut] |
| Maintainer: | Iago Mosqueira <[email protected]> |
| License: | GPL-2 |
| Version: | 2.6.1 |
| Built: | 2026-05-22 08:50:28 UTC |
| Source: | https://github.com/flr/FLFleet |